.. default-intersphinx:: django4.2 djblets5.x python3


===========================
Djblets 5.0.2 Release Notes
===========================

**Release date**: June 12, 2024


Installation
============

To install Djblets 5.0.2, run:

.. code-block:: console

   $ pip3 install Djblets==5.0.2


To learn more, see:

* `Documentation <https://www.reviewboard.org/docs/djblets/5.x/>`_
* `Djblets on PyPI <https://pypi.org/project/Djblets/>`_
* `Djblets on GitHub <https://github.com/djblets/djblets/>`_


.. _Django: https://www.djangoproject.com/


djblets.extensions
==================

* Fixed a regression when packaging extensions against a system install of
  the application supporting extensions.

  Djblets 5 rewrote much of the extension package-building infrastructure,
  and introduced a regression where some paths were being prematurely
  validated against the system install of the application. This behaved as
  expected with a developer install of the application.

  We've restored the original logic here, ensuring that packages can be
  safely built against system installs of the application.


Contributors
============

* Christian Hammond
* David Trowbridge
* Michelle Aubin
